# Changelog

<!--next-version-placeholder-->

## v1.0.1 (2022-05-31)
### Fix
* Update URI to png ([`e810a79`](https://github.com/Stephen-RA-King/pynnacle/commit/e810a7956b265abcb7ebf1cafce76554ee63309e))
* Refresh project support files ([`ee21182`](https://github.com/Stephen-RA-King/pynnacle/commit/ee21182bdb771b4a45dd64d4e2088bf28eca89cd))

## 0.1.0 (2022-05-31)

### First Release of 'pynnacle'



<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pynnacle)
